@@ -53,15 +53,11 @@ def remove_old_files():
                 etld_lib_functions.logger.error(f"{e}")
                 exit(1)
     try:
-        if Path(etld_lib_config.asset_inventory_sqlite_file).is_file():
-            etld_lib_functions.logger.info(f"Removing old sqlite file: {etld_lib_config.asset_inventory_sqlite_file}")
-            Path(etld_lib_config.asset_inventory_sqlite_file).unlink()
-        if Path(etld_lib_config.asset_inventory_shelve_file).is_file():
-            etld_lib_functions.logger.info(f"Removing old shelve file: {etld_lib_config.asset_inventory_shelve_file}")
-            Path(etld_lib_config.asset_inventory_shelve_file).unlink()
-        if Path(etld_lib_config.asset_inventory_csv_file).is_file():
-            etld_lib_functions.logger.info(f"Removing old csv file: {etld_lib_config.asset_inventory_csv_file}")
-            Path(etld_lib_config.asset_inventory_csv_file).unlink()
+        for file_name in etld_lib_config.asset_inventory_data_files:
+            if Path(file_name).is_file():
+                etld_lib_functions.logger.info(f"Removing old asset inventory file: {str(file_name)}")
+                Path(file_name).unlink()
+
     except Exception as e:
         etld_lib_functions.logger.error(f"{e}")
         exit(1)
@@ -103,23 +99,25 @@ def get_asset_inventory_data():
 
     # Get Asset Inventory Count
     batch_number_str = f'batch_{batch_number:06d}'
-    asset_inventory_extract.asset_inventory_extract_count(
+    cred_dict = asset_inventory_extract.asset_inventory_extract_count(
         asset_last_updated=etld_lib_config.asset_inventory_asset_last_updated,
         last_seen_assetid=str(batch_info['lastSeenAssetId']),
         utc_datetime=utc_datetime,
         batch_number=batch_number_str,
-        proc_dict=qualys_headers_multi_proc_dict)
+        proc_dict=qualys_headers_multi_proc_dict,
+        cred_dict={})
 
     # Extract Assets
     while has_more_records == '1':
         batch_number = batch_number + 1
         batch_number_str = f'batch_{batch_number:06d}'
-        asset_inventory_extract.asset_inventory_extract(
+        cred_dict = asset_inventory_extract.asset_inventory_extract(
             asset_last_updated=etld_lib_config.asset_inventory_asset_last_updated,
             last_seen_assetid=str(batch_info['lastSeenAssetId']),
             utc_datetime=utc_datetime,
             batch_number=batch_number_str,
-            proc_dict=qualys_headers_multi_proc_dict)
+            proc_dict=qualys_headers_multi_proc_dict,
+            cred_dict=cred_dict)
         batch_info = get_next_batch(json_file=asset_inventory_extract.json_file)
         etld_lib_functions.logger.info(f"batch_info: {batch_info}")
         if 'hasMore' in batch_info.keys():
@@ -129,10 +127,16 @@ def get_asset_inventory_data():
             etld_lib_functions.logger.error(f"batch_info: {batch_info}")
             exit(1)
         if batch_number_str in qualys_headers_multi_proc_dict.keys():
-            x_ratelimit_remaining = qualys_headers_multi_proc_dict[batch_number_str]['x_ratelimit_remaining']
-            if int(x_ratelimit_remaining) < 100:
-                # Sleep for 5 minutes and run next.
-                etld_lib_functions.logger.warning(f"x_ratelimit_remaining is less than 100. "
+            if 'x_ratelimit_remaining' in qualys_headers_multi_proc_dict[batch_number_str].keys():
+                x_ratelimit_remaining = qualys_headers_multi_proc_dict[batch_number_str]['x_ratelimit_remaining']
+                if int(x_ratelimit_remaining) < 100:
+                    # Sleep for 5 minutes and run next.
+                    etld_lib_functions.logger.warning(f"x_ratelimit_remaining is less than 100. "
+                                                      f"Sleeping 5 min.  batch_info: {batch_info}, "
+                                                      f"header_info: {qualys_headers_multi_proc_dict[batch_number_str]}")
+                    time.sleep(300)
+            else:
+                etld_lib_functions.logger.warning(f"x_ratelimit_remaining missing from Qualys Header. "
                                                   f"Sleeping 5 min.  batch_info: {batch_info}, "
                                                   f"header_info: {qualys_headers_multi_proc_dict[batch_number_str]}")
                 time.sleep(300)
