@@ -4,16 +4,21 @@ import time
 from pathlib import Path
 import re
 from shelve import DbfilenameShelf
+from typing import Dict, Any
 
 from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_datetime as etld_lib_datetime
 global count_items_added_to_shelve
+global count_items_added_to_shelve_display_progress
 global shelve_database
+global shelve_software_unique_database
+global shelve_software_assetid_database
 global shelve_temp_database
 global json_dir
 global json_dir_search_glob
 global json_file_list
+global software_full_name_dict
 
 
 def transform_epoch_dates(item):
@@ -59,6 +64,7 @@ def transform_epoch_dates(item):
 
 def transform_json_item_to_shelve(item=None, sd=None, sd_file=None):
     global count_items_added_to_shelve
+    global count_items_added_to_shelve_display_progress
     global json_dir
     global json_dir_search_glob
 
@@ -68,7 +74,13 @@ def transform_json_item_to_shelve(item=None, sd=None, sd_file=None):
     for i in range(max_retries):
         try:
             sd[str(item_key)] = item
-            count_items_added_to_shelve = count_items_added_to_shelve + 1
+            count_items_added_to_shelve += 1
+            count_items_added_to_shelve_display_progress += 1
+            if count_items_added_to_shelve_display_progress > 9999:
+                count_items_added_to_shelve_display_progress = 0
+                etld_lib_functions.logger.info(f"asset inventory shelve records written: "
+                                               f"{count_items_added_to_shelve:,}")
+
         except Exception as e:
             time.sleep(1)
             etld_lib_functions.logger.warning(
@@ -86,6 +98,32 @@ def transform_json_item_to_shelve(item=None, sd=None, sd_file=None):
     return True
 
 
+def asset_inventory_shelve_software(item):
+    global shelve_software_unique_database
+    global shelve_software_assetid_database
+
+    if item['softwareListData'] is not None:
+        with shelve.open(str(shelve_software_unique_database),
+                         flag='c') as software_unique_dict:
+            with shelve.open(str(shelve_software_assetid_database),
+                             flag='c') as software_assetid_dict:
+                for software_item in item['softwareListData']['software']:
+                    if 'fullName' in software_item:
+                        assetid_fullname = f"{item['assetId']}_{software_item['fullName']}"
+                        if assetid_fullname not in software_assetid_dict:
+                            software_assetid_dict[assetid_fullname] = ""
+
+                        fullname = f"{software_item['fullName']}"
+                        if fullname not in software_assetid_dict:
+                            if 'lifecycle' in software_item:
+                                software_unique_dict[fullname] = software_item['lifecycle']
+                            else:
+                                software_unique_dict[fullname] = {'gaDate': None, 'eolDate': None, 'eosDate': None,
+                                                                  'stage': None,
+                                                                  'lifeCycleConfidence': 'Not Available QETL',
+                                                                  'eolSupportStage': '', 'eosSupportStage': ''}
+
+
 def asset_inventory_shelve():
     global count_items_added_to_shelve
     global shelve_database
@@ -109,6 +147,7 @@ def asset_inventory_shelve():
                                 # etld_lib_functions.logger.info(f"Asset already exists in shelve: {asset_id}")
                             else:
                                 transform_json_item_to_shelve(item, sd, str(shelve_database))
+                                asset_inventory_shelve_software(item)
 
     except Exception as e:
         etld_lib_functions.logger.error(f"Exception: {e}")
@@ -128,6 +167,12 @@ def end_msg_asset_inventory_shelve():
         etld_lib_functions.log_file_info(json_file, 'in')
     etld_lib_functions.log_dbm_info(str(shelve_database))
     etld_lib_functions.log_file_info(str(shelve_database))
+    etld_lib_functions.log_file_info(str(shelve_database))
+    etld_lib_functions.log_file_info(str(shelve_software_unique_database))
+    etld_lib_functions.log_file_info(str(shelve_software_assetid_database))
+    etld_lib_functions.log_dbm_count_of_keys_found(str(shelve_software_unique_database))
+    etld_lib_functions.log_dbm_count_of_keys_found(str(shelve_software_assetid_database))
+
     etld_lib_functions.logger.info(f"end")
 
 
@@ -137,13 +182,19 @@ def start_msg_asset_inventory_shelve():
 
 def setup_shelve_vars():
     global count_items_added_to_shelve
+    global count_items_added_to_shelve_display_progress
     global shelve_database
+    global shelve_software_unique_database
+    global shelve_software_assetid_database
     global shelve_temp_database
     global json_dir
     global json_dir_search_glob
 
     count_items_added_to_shelve = 0
+    count_items_added_to_shelve_display_progress = 0
     shelve_database = etld_lib_config.asset_inventory_shelve_file
+    shelve_software_unique_database = etld_lib_config.asset_inventory_shelve_software_unique_file
+    shelve_software_assetid_database = etld_lib_config.asset_inventory_shelve_software_assetid_file
     shelve_temp_database = etld_lib_config.asset_inventory_temp_shelve_file
     json_dir = etld_lib_config.asset_inventory_json_dir
     json_dir_search_glob = 'asset_inventory_utc*.json'
