@@ -13,7 +13,8 @@ def asset_inventory_dist():
         )
         api_dist.copy_results_to_external_target(file_paths, etld_lib_config.asset_inventory_export_dir)
     except Exception as e:
-        etld_lib_functions.logger.error(f"Exception: {e}")
+        etld_lib_functions.logger.error(f"Program aborted, ensure etld_lib_config_settings.yaml distribution "
+                                        f"directory exists or is set to default: Exception: {e}")
         exit(1)
 
 
