@@ -106,7 +106,6 @@ def host_list_detection_end_wrapper():
 
 def host_list_detection_etl_workflow():
     try:
-
         host_list_detection_start_wrapper()
         update_host_list_for_input_to_host_list_detection_wrapper()
         host_list_detection_extract_wrapper()
@@ -114,11 +113,17 @@ def host_list_detection_etl_workflow():
         host_list_detection_to_json_wrapper()
         host_list_detection_to_csv_wrapper()
         update_knowledgebase_for_input_to_host_list_detection_sqlite_wrapper()
+    except Exception as e:
+        etld_lib_functions.logger.error(f"Error occurred in initial steps, please investigate {sys.argv}")
+        etld_lib_functions.logger.error(f"Exception: {e}")
+        exit(1)
+
+    try:
         host_list_detection_to_sqlite_wrapper()
         host_list_detection_distribution_wrapper()
         host_list_detection_end_wrapper()
     except Exception as e:
-        etld_lib_functions.logger.error(f"Error occurred, please investigate {sys.argv}")
+        etld_lib_functions.logger.error(f"Error occurred final step, please investigate {sys.argv}")
         etld_lib_functions.logger.error(f"Exception: {e}")
         exit(1)
 
