@@ -15,7 +15,7 @@ def host_list_detection_sqlite():
     etld_lib_sqlite_tables.bulk_insert_csv_file(etld_lib_config.host_list_detection_table_name,
                                     etld_lib_config.host_list_detection_csv_file,
                                     host_list_detection_updated_csv_columns,
-                                    etld_lib_config.host_list_detection_sqlite_file)
+                                    etld_lib_config.host_list_detection_sqlite_file, "host list detection")
 
 
 def start_msg_host_list_detection_sqlite():
