@@ -15,7 +15,7 @@ def kb_sqlite():
     etld_lib_sqlite_tables.bulk_insert_csv_file(etld_lib_config.kb_table_name,
                                                 etld_lib_config.kb_csv_file,
                                                 etld_lib_functions.kb_csv_columns(),
-                                                kb_sqlite_file)
+                                                kb_sqlite_file, "knowledgebase")
 
 
 def start_msg_kb_sqlite():
