@@ -94,10 +94,14 @@ global asset_inventory_asset_last_updated
 global asset_inventory_payload_option
 global asset_inventory_json_batch_file
 global asset_inventory_json_dir
+global asset_inventory_shelve_software_assetid_file
+global asset_inventory_shelve_software_unique_file
 global asset_inventory_shelve_file
 global asset_inventory_sqlite_file
 global asset_inventory_csv_truncate_cell_limit
 global asset_inventory_csv_file
+global asset_inventory_csv_software_assetid_file
+global asset_inventory_csv_software_unique_file
 global asset_inventory_json_file
 global asset_inventory_log_file
 global asset_inventory_lock_file
@@ -106,11 +110,13 @@ global asset_inventory_concurrency_limit
 global asset_inventory_multi_proc_batch_size
 global asset_inventory_limit_hosts
 global asset_inventory_table_name
+global asset_inventory_table_name_software_unique
+global asset_inventory_table_name_software_assetid
 global asset_inventory_data_files
 global asset_inventory_temp_shelve_file
 global asset_inventory_present_csv_cell_as_json
 
-# Initialize Some Globals
+# initialize some globals
 
 qetl_create_user_dirs_ok_flag = False      # Automatically create unknown user directories default - False
 qetl_manage_user_selected_datetime = None  # Initialize qetl_manage_user datetime to None
@@ -689,14 +695,20 @@ def setup_asset_inventory_vars():
     global asset_inventory_json_batch_file
     global asset_inventory_json_dir
     global asset_inventory_shelve_file
+    global asset_inventory_shelve_software_assetid_file
+    global asset_inventory_shelve_software_unique_file
     global asset_inventory_sqlite_file
     global asset_inventory_csv_file
+    global asset_inventory_csv_software_assetid_file
+    global asset_inventory_csv_software_unique_file
     global asset_inventory_csv_truncate_cell_limit
     global asset_inventory_json_file
     global asset_inventory_log_file
     global asset_inventory_lock_file
     global asset_inventory_log_rotate_file
     global asset_inventory_table_name
+    global asset_inventory_table_name_software_assetid
+    global asset_inventory_table_name_software_unique
     global asset_inventory_data_files
     global asset_inventory_temp_shelve_file
 
@@ -705,15 +717,26 @@ def setup_asset_inventory_vars():
     asset_inventory_json_batch_file = Path(asset_inventory_json_dir, "asset_inventory_rename_me_to_batch.xml")
     asset_inventory_temp_shelve_file = Path(asset_inventory_json_dir, "asset_inventory_temp_shelve.db")
     asset_inventory_shelve_file = Path(asset_inventory_data_dir, "asset_inventory_shelve")
+    asset_inventory_shelve_software_assetid_file = \
+        Path(asset_inventory_data_dir, "asset_inventory_shelve_software_assetid")
+    asset_inventory_shelve_software_unique_file = \
+        Path(asset_inventory_data_dir, "asset_inventory_shelve_software_unique")
     asset_inventory_sqlite_file = Path(asset_inventory_data_dir, "asset_inventory_sqlite.db")
     asset_inventory_csv_file = Path(asset_inventory_data_dir, "asset_inventory.csv")
+    asset_inventory_csv_software_assetid_file = Path(asset_inventory_data_dir, "asset_inventory_software_assetid.csv")
+    asset_inventory_csv_software_unique_file = Path(asset_inventory_data_dir, "asset_inventory_software_unique.csv")
     asset_inventory_json_file = Path(asset_inventory_data_dir, "asset_inventory.json")
     asset_inventory_log_file = Path(qetl_user_log_dir, "asset_inventory.log")
     asset_inventory_lock_file = Path(qetl_user_log_dir, ".asset_inventory.lock")
     asset_inventory_log_rotate_file = Path(qetl_user_log_dir, "asset_inventory.1.log")
     asset_inventory_table_name = 'Q_Asset_Inventory'
+    asset_inventory_table_name_software_assetid = 'Q_Asset_Inventory_Software_AssetId'
+    asset_inventory_table_name_software_unique = 'Q_Asset_Inventory_Software_Unique'
     asset_inventory_data_files = [asset_inventory_shelve_file, asset_inventory_sqlite_file,
-                                  asset_inventory_csv_file, asset_inventory_json_file]
+                                  asset_inventory_csv_file, asset_inventory_csv_software_unique_file,
+                                  asset_inventory_csv_software_assetid_file, asset_inventory_json_file,
+                                  asset_inventory_shelve_software_assetid_file,
+                                  asset_inventory_shelve_software_unique_file]
 
 
 def setup_completed():
