@@ -23,7 +23,9 @@ global login_failed
 global login_gateway_failed
 global http_return_code
 global platform_url
+global injected_stdin_cred
 
+#injected_stdin_cred = {'username': 'tamab_dt4', 'password': 'no.can.do.Q1', 'api_fqdn_server': 'qualysapi.qualys.com'}
 
 # https://www.qualys.com/platform-identification/
 platform_url = {
@@ -111,21 +113,48 @@ def update_cred(new_cred):
         oschmod.set_mode(str(cred_file), "u+rw,u-x,go-rwx")
 
 
-def get_cred():
-    if not Path.is_file(cred_file):
-        cred_example_file_path = Path(etld_lib_functions.qetl_code_dir, "qualys_etl", "etld_templates", ".etld_cred.yaml")
-        destination_file_path = Path(cred_dir, ".etld_cred.yaml")
-        shutil.copy(str(cred_example_file_path), str(destination_file_path), follow_symlinks=True)
-        cred_example_file = open(str(cred_example_file_path), "r", encoding='utf-8')
-        cred_example = cred_example_file.read()
-        cred_example_file.close()
-        local_date = etld_lib_datetime.get_local_date() # Add date updated to file
-        cred_example = re.sub('\$DATE', local_date, cred_example)
-        cred_file_example = open(str(cred_file), 'w', encoding='utf-8')
-        cred_file_example.write(cred_example)
-        cred_file_example.close()
+def get_authorization(username, password):
+    authorization = 'Basic ' + \
+                    base64.b64encode(f"{username}:{password}".encode('utf-8')).decode('utf-8')
+    return authorization
 
-    oschmod.set_mode(str(cred_file), "u+rw,u-x,go-rwx")
+
+def get_env_cred() -> dict:
+    username = ""
+    password = ""
+    api_fqdn_server = ""
+    gateway_fqdn_server = ""
+    authorization = ""
+    bearer = ""
+
+    k = os.environ.keys()
+    if 'q_username' in k:
+        username = os.environ.get('q_username')
+    if 'q_password' in k:
+        password = os.environ.get('q_password')
+    if 'q_api_fqdn_server' in k:
+        api_fqdn_server = os.environ.get('q_api_fqdn_server')
+    if 'q_gateway_fqdn_server' in k:
+        gateway_fqdn_server = os.environ.get('q_gateway_fqdn_server')
+    if 'q_bearer' in k:
+        bearer = os.environ.get('q_bearer')
+
+    if username != "" and password != "" and api_fqdn_server != "":
+        authorization = get_authorization(username, password)
+        etld_lib_functions.logger.info(f"Not using .etld_cred.yaml. Found env credentials, "
+                                       f"username: {username}, api_fqdn_server:  {api_fqdn_server}")
+        if gateway_fqdn_server == "":
+            gateway_fqdn_server = f"{platform_url.get(api_fqdn_server)}"
+
+    return {'api_fqdn_server': api_fqdn_server,
+            'gateway_fqdn_server': gateway_fqdn_server,
+            'authorization': authorization,
+            'username': username,
+            'password': password,
+            'bearer': bearer}
+
+
+def get_filesystem_cred():
     try:
         with open(cred_file, 'r', encoding='utf-8') as cred_yaml_file:
             cred = yaml.safe_load(cred_yaml_file)
@@ -149,6 +178,7 @@ def get_cred():
                     'authorization': authorization,
                     'username': username,
                     'password': password}
+
     except Exception as e:
         etld_lib_functions.logger.error(f"Please add your subscription credentials to the:  {cred_file}")
         etld_lib_functions.logger.error(f"   ** Warning: Ensure Credential File permissions are correct for your company.")
@@ -159,6 +189,39 @@ def get_cred():
         exit(1)
 
 
+def get_cred(cred_dict=dict()):
+    if not Path.is_file(cred_file):
+        cred_example_file_path = Path(etld_lib_functions.qetl_code_dir, "qualys_etl", "etld_templates", ".etld_cred.yaml")
+        destination_file_path = Path(cred_dir, ".etld_cred.yaml")
+        shutil.copy(str(cred_example_file_path), str(destination_file_path), follow_symlinks=True)
+        cred_example_file = open(str(cred_example_file_path), "r", encoding='utf-8')
+        cred_example = cred_example_file.read()
+        cred_example_file.close()
+        local_date = etld_lib_datetime.get_local_date() # Add date updated to file
+        cred_example = re.sub('\$DATE', local_date, cred_example)
+        cred_file_example = open(str(cred_file), 'w', encoding='utf-8')
+        cred_file_example.write(cred_example)
+        cred_file_example.close()
+
+    oschmod.set_mode(str(cred_file), "u+rw,u-x,go-rwx")
+    if 'q_password' in os.environ.keys():
+        cred = get_env_cred()
+    else:
+        cred = get_filesystem_cred()
+
+    if 'bearer' in cred_dict.keys():
+        cred['bearer'] = cred_dict['bearer']
+    else:
+        cred['bearer'] = ""
+
+    return {'api_fqdn_server': cred['api_fqdn_server'],
+            'gateway_fqdn_server': cred['gateway_fqdn_server'],
+            'authorization': cred['authorization'],
+            'username': cred['username'],
+            'password': cred['password'],
+            'bearer': cred['bearer']}
+
+
 def get_cookie(update_cookie=True):
     one_hour = (60*60)  # (Sec * Min)
     try:
@@ -281,6 +344,84 @@ def qualys_gateway_login():
         exit(1)
 
 
+def get_bearer_stored_in_env(update_bearer=True, cred={}):
+    one_hour = (60*60)  # (Sec * Min)
+    try:
+        if update_bearer:
+            cred = qualys_gateway_login_store_in_env(cred_dict=cred)
+        if cred['bearer'] == "":
+            cred = qualys_gateway_login_store_in_env(cred_dict=cred)
+        elif Path(bearer_file).is_file():
+            age_of_file = etld_lib_datetime.get_seconds_since_last_file_modification(Path(bearer_file))
+            if age_of_file > one_hour:
+                cred = qualys_gateway_login_store_in_env(cred_dict=cred)
+        else:
+            cred = qualys_gateway_login_store_in_env(cred_dict=cred)
+
+    except Exception as e:
+        etld_lib_functions.logger.error(f"               Credentials Dir:  {cred_dir}")
+        etld_lib_functions.logger.error(f"              Credentials File:  {cred_file}")
+        etld_lib_functions.logger.error(f"Exception: {e}")
+        exit(1)
+
+    return cred
+
+
+def qualys_gateway_login_store_in_env(cred_dict={}):
+    global login_gateway_failed
+    global http_return_code
+
+    login_gateway_failed = True
+    if 'gateway_fqdn_server' in cred_dict:
+        if cred_dict['gateway_fqdn_server'] is None:
+            etld_lib_functions.logger.error(f"Please add gateway_fqdn_server credentials file or environment.")
+            exit(1)
+
+    # Login to Qualys, return bearer token.
+    url = f"https://{cred_dict['gateway_fqdn_server']}/auth"  # Qualys Endpoint
+    payload = {'token': 'true', 'password': cred_dict['password'], 'username': cred_dict['username'],
+               'permissions': 'true'}
+    payload = urlencode(payload, quote_via=quote_plus)
+
+    headers = {'X-Requested-With': f'qualysetl_v{qualys_etl.__version__}',
+               'Content-Type': 'application/x-www-form-urlencoded',
+               'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
+
+    try:
+        response = requests.request("POST", url, headers=headers, data=payload)
+        http_return_code = response.status_code
+        if response.status_code == 201:
+            with open(bearer_file, 'w', encoding='utf-8') as bearerfile:
+                bearerfile.write(f"DUMMY ENTRY FOR TIME TRACKING OF BEARER AGE")
+            bearer = f"Bearer {response.text}"
+            cred_dict['bearer'] = bearer
+            oschmod.set_mode(str(bearer_file), "u+rw,u-x,go-rwx")
+            etld_lib_functions.logger.info(f"LOGIN - Qualys Gateway Login Success with user: {cred_dict['username']}")
+            login_gateway_failed = False
+        else:
+            etld_lib_functions.logger.error(f"Fail - Qualys Gateway Login Failed with user: {cred_dict['username']}")
+            etld_lib_functions.logger.error(f"       HTTP {response.status_code}")
+            etld_lib_functions.logger.error(f"       Verify Qualys username, password and "
+                                            f"gateway_fqdn_server in Credentials File or environment")
+            etld_lib_functions.logger.error(f"             Credentials Env:")
+            etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
+            etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
+            etld_lib_functions.logger.error(f"         gateway_fqdn_server:  {cred_dict['gateway_fqdn_server']}")
+            exit(1)
+    except requests.exceptions.RequestException as e:
+        etld_lib_functions.logger.error(f"Fail - Qualys Gateway Login Failed with user: {cred_dict['username']}")
+        etld_lib_functions.logger.error(f"       Verify Qualys username, password and "
+                                        f"api_fqdn_server, and gateway_fqdn_server in Credentials File")
+        etld_lib_functions.logger.error(f"             Credentials Env:")
+        etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
+        etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
+        etld_lib_functions.logger.error(f"         gateway_fqdn_server:  {cred_dict['gateway_fqdn_server']}")
+        etld_lib_functions.logger.error(f"Exception: {e}")
+        exit(1)
+
+    return cred_dict
+
+
 def qualys_login():
     global use_cookie
     global login_failed
@@ -302,7 +443,8 @@ def qualys_login():
             cookie_dict = response.cookies.get_dict()
             cookie = f"DWRSESSIONID={cookie_dict['DWRSESSIONID']}; QualysSession={cookie_dict['QualysSession']}"
             with open(cookie_file, 'w', encoding='utf-8') as cookiefile:
-                cookiefile.write(cookie)
+                # cookiefile.write(cookie)
+                cookiefile.write("DUMMY")
             oschmod.set_mode(str(cookie_file), "u+rw,u-x,go-rwx")
             etld_lib_functions.logger.info(f"LOGIN - Qualys Login Success with user: {cred_dict['username']}")
             login_failed = False
@@ -315,7 +457,7 @@ def qualys_login():
             etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
             etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
             exit(1)
-        use_cookie = True
+        use_cookie = False
     except requests.exceptions.RequestException as e:
         etld_lib_functions.logger.error(f"Fail - Qualys Login Failed with user")
         etld_lib_functions.logger.error(f"       Verify Qualys username, password and api_fqdn_server in Credentials File")
@@ -328,21 +470,22 @@ def qualys_login():
 
 def qualys_logout():
     global use_cookie
-    cred_dict = get_cred()
-    url = f"https://{cred_dict['api_fqdn_server']}/api/2.0/fo/session/"  # Qualys Endpoint
-    payload = {'action': 'logout'}
-    headers = {'X-Requested-With': f'qualysetl_v{qualys_etl.__version__}',
-               'Content-Type': 'application/x-www-form-urlencoded', 'Cookie': get_cookie(update_cookie=False),
-               'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
-    try:
-        response = requests.request("POST", url, headers=headers, data=payload)
-        if response.status_code == 200:
-            etld_lib_functions.logger.info(f"LOGOUT - Qualys Logout Success with user: {cred_dict['username']}")
-        else:
-            etld_lib_functions.logger.warning(f"LOGOUT FAILED - probably stale cookie, continue with warning")
-    except Exception as e:
-        etld_lib_functions.logger.warning(f"LOGOUT FAILED, probably connectivity issue, continue with warning")
-        etld_lib_functions.logger.warning(f"Exception: {e}")
+    if use_cookie:
+        cred_dict = get_cred()
+        url = f"https://{cred_dict['api_fqdn_server']}/api/2.0/fo/session/"  # Qualys Endpoint
+        payload = {'action': 'logout'}
+        headers = {'X-Requested-With': f'qualysetl_v{qualys_etl.__version__}',
+                   'Content-Type': 'application/x-www-form-urlencoded', 'Cookie': get_cookie(update_cookie=False),
+                   'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
+        try:
+            response = requests.request("POST", url, headers=headers, data=payload)
+            if response.status_code == 200:
+                etld_lib_functions.logger.info(f"LOGOUT - Qualys Logout Success with user: {cred_dict['username']}")
+            else:
+                etld_lib_functions.logger.warning(f"LOGOUT FAILED - probably stale cookie, continue with warning")
+        except Exception as e:
+            etld_lib_functions.logger.warning(f"LOGOUT FAILED, probably connectivity issue, continue with warning")
+            etld_lib_functions.logger.warning(f"Exception: {e}")
 
     use_cookie = False
 
