@@ -7,6 +7,8 @@ import sys
 import time
 import getpass
 import dbm
+import dbm.gnu
+from os.path import exists
 import re
 from pathlib import Path
 from importlib import util as importlib_util
@@ -173,6 +175,31 @@ def asset_inventory_csv_columns():  # Return list of csv columns updated 0.6.111
     return csv_columns
 
 
+def asset_inventory_software_assetid_csv_columns():
+
+    csv_columns = [
+        'id_pk',
+        'assetId', 'fullName'
+    ]
+    return csv_columns
+
+
+def asset_inventory_software_assetid_csv_column_types():
+
+    csv_columns = {
+        'id_pk': 'INTEGER', 'assetId': 'TEXT', 'fullName': 'TEXT'
+    }
+    return csv_columns
+
+
+def asset_inventory_software_unique_csv_columns():
+    csv_columns = [
+        'fullName',
+        'gaDate', 'eolDate', 'eosDate', 'stage', 'lifeCycleConfidence', 'eolSupportStage', 'eosSupportStage'
+    ]
+    return csv_columns
+
+
 def check_python_version():
     py_version = sys.version.split('\n')
     try:
@@ -323,13 +350,23 @@ def set_qetl_code_dir(log=True): # Module Directories
 
 
 def log_dbm_info(file_name, msg=""):
-    dbm_type = get_dbm_type(str(file_name))
-    logger.info(f"{msg}dbm type - {dbm_type} - {str(file_name)}")
-    if dbm_type == "dbm.gnu" or dbm_type is None:
-        pass
-    else:
-        logger.info(f"{msg}dbm type warning - {dbm_type} may lead to inconsistent results.")
-        logger.info(f"{msg}dbm type warning - {dbm_type} move to linux gnu dbm.")
+    if exists(str(file_name)):
+        dbm_type = get_dbm_type(str(file_name))
+        logger.info(f"{msg}dbm type - {dbm_type} - {str(file_name)}")
+        if dbm_type == "dbm.gnu" or dbm_type is None:
+            pass
+        else:
+            logger.info(f"{msg}dbm type warning - {dbm_type} may lead to inconsistent results.")
+            logger.info(f"{msg}dbm type warning - {dbm_type} move to linux gnu dbm.")
+
+
+def log_dbm_count_of_keys_found(file_name):
+    if exists(str(file_name)):
+        dbm_type = get_dbm_type(str(file_name))
+        if dbm_type == "dbm.gnu" or dbm_type is None:
+            with dbm.gnu.open(str(file_name), 'rf') as sd:
+                count = len(sd)
+                logger.info(f"keys found: {count:,} in dbm.gnu shelve: {str(file_name)}")
 
 
 def get_formatted_file_info_dict(file_name):
