@@ -6,22 +6,44 @@ from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
 global count_rows_added_to_table
 
 
-def create_table_statement(primary_key, table_name, csv_columns):
+def create_table_statement(primary_key, table_name, csv_columns, csv_column_types={}):
     table_statement = f"CREATE TABLE {table_name} (\n"
-    table_statement = f"{table_statement}{primary_key} CHAR PRIMARY KEY NOT NULL,\n"
+    if primary_key in csv_column_types.keys():
+        table_statement = f"{table_statement}{primary_key} {csv_column_types[primary_key]} PRIMARY KEY NOT NULL,\n"
+    else:
+        table_statement = f"{table_statement}{primary_key} CHAR PRIMARY KEY NOT NULL,\n"
+
     for column in csv_columns:
         if primary_key != column:
-            table_statement = f"{table_statement}{column} CHAR,\n"
+            if column in csv_column_types.keys():
+                column_type = csv_column_types[column]
+                table_statement = f"{table_statement}{column} {column_type},\n"
+            else:
+                table_statement = f"{table_statement}{column} CHAR,\n"
+
     table_statement = re.sub(",\n$", "", table_statement)
     table_statement = table_statement + ");"
     return table_statement
 
 
-def create_table(table_name, csv_columns, sqlite_file, key):
+def create_table_statement_no_primary_key(table_name, csv_columns):
+    table_statement = f"CREATE TABLE {table_name} (\n"
+    for column in csv_columns:
+        table_statement = f"{table_statement}{column} CHAR,\n"
+    table_statement = re.sub(",\n$", "", table_statement)
+    table_statement = table_statement + ");"
+    return table_statement
+
+
+def create_table(table_name, csv_columns, sqlite_file, key=False, csv_column_types={}):
     try:
         conn = sqlite3.connect(sqlite_file)
         conn.execute(f"DROP TABLE IF EXISTS {table_name};")
-        table_statement = create_table_statement(key, table_name, csv_columns)
+        if key is False:
+            table_statement = create_table_statement_no_primary_key(table_name, csv_columns)
+        else:
+            table_statement = create_table_statement(key, table_name, csv_columns, csv_column_types)
+
         conn.execute(table_statement)
         conn.commit()
         conn.close()
@@ -32,7 +54,7 @@ def create_table(table_name, csv_columns, sqlite_file, key):
         exit(1)
 
 
-def bulk_insert_csv_file(table_name, csv_file_name, csv_columns, sqlite_file):
+def bulk_insert_csv_file(table_name, csv_file_name, csv_columns, sqlite_file, message=""):
     global count_rows_added_to_table
     count_rows_added_to_table_display_progress = 0
     csv.field_size_limit(sys.maxsize)
@@ -61,7 +83,7 @@ def bulk_insert_csv_file(table_name, csv_file_name, csv_columns, sqlite_file):
                 count_rows_added_to_table += 1
                 count_rows_added_to_table_display_progress += 1
                 if count_rows_added_to_table_display_progress > 9999:
-                    etld_lib_functions.logger.info(f"sqlite rows written: {count_rows_added_to_table}")
+                    etld_lib_functions.logger.info(f"sqlite {message} rows written: {count_rows_added_to_table}")
                     count_rows_added_to_table_display_progress = 0
 
             if len(csv_row_list) > 0:
