@@ -3,10 +3,12 @@
 import argparse
 import os
 import sys
+import select
 import re
 import logging
 import time
 import getpass
+import json
 from pathlib import Path
 import qualys_etl.etld_lib.etld_lib_functions as etld_lib_functions
 import qualys_etl.etld_lib.etld_lib_config as etld_lib_config
@@ -116,6 +118,134 @@ def update_password(cred):
     pass
 
 
+def if_prompt_credentials():
+    def stdin_help():
+        print(f"You selected -p prompt, but the data provided is invalid.")
+        print(f"Please check your values and re-enter.")
+
+    if command_line_arguments.prompt_credentials is not None:
+        while True:
+            username = input("Enter username: ")
+            password = getpass.getpass()
+            api_fqdn_server = input("Enter api_fqdn_server: ")
+            gateway_fqdn_server = input("Optionally enter gateway_fqdn_server: ")
+            if validate_username(username) and validate_password(password) and validate_api_fqdn_server(api_fqdn_server):
+                os.environ['q_username'] = username
+                os.environ['q_password'] = password
+                os.environ['q_api_fqdn_server'] = api_fqdn_server
+                break
+            else:
+                stdin_help()
+                continue
+
+        if validate_gateway_fqdn_server(gateway_fqdn_server):
+            os.environ['q_gateway_fqdn_server'] = gateway_fqdn_server
+        else:
+            os.environ['q_gateway_fqdn_server'] = ""
+        return True
+    else:
+        return False
+
+
+def valid_json(json_data):
+    try:
+        json.loads(json_data)
+    except ValueError as err:
+        return False
+    return True
+
+
+def if_stdin_credentials():
+    def stdin_help():
+        print(f"You selected -s stdin, but the data provided is invalid.")
+        print('Example of valid json (gateway is optional): ')
+        print('{"q_username":"your userid", "q_password":"your password", "q_api_fqdn_server":"api fqdn", '
+              '"q_gateway_fqdn_server": "gateway api fqdn"}')
+        print(f"Please rerun when ready.")
+
+    if command_line_arguments.stdin_credentials is not None:
+        input_fd_ready, output_fd_ready, exception_fd_ready = select.select([sys.stdin], [], [], 5)
+        stdin_data = ""
+        if input_fd_ready:
+            for i in sys.stdin.readlines():
+                stdin_data = f"{stdin_data}{i}"
+            if valid_json(stdin_data):
+                pass
+            else:
+                print("Invalid JSON...")
+                stdin_help()
+                exit(1)
+        else:
+            print("No data set through stdin...")
+            stdin_help()
+            exit(1)
+
+        cred = json.loads(stdin_data)
+        if 'q_username' in cred.keys() and 'q_password' in cred.keys() and 'q_api_fqdn_server' in cred.keys():
+            pass
+        else:
+            print("Missing q_username, q_password or q_api_fqdn_server keys...")
+            stdin_help()
+            exit(1)
+
+        api_fqdn_server = cred['q_api_fqdn_server']
+        username = cred['q_username']
+        password = cred['q_password']
+        gateway_fqdn_server = ""
+        if 'q_gateway_fqdn_server' in cred.keys():
+            gateway_fqdn_server = cred['q_gateway_fqdn_server']
+
+        if validate_username(username) and validate_password(password) and validate_api_fqdn_server(api_fqdn_server):
+            os.environ['q_username'] = username
+            os.environ['q_password'] = password
+            os.environ['q_api_fqdn_server'] = api_fqdn_server
+        else:
+            print("Invalid q_username, q_password or q_api_fqdn_server...")
+            stdin_help()
+            exit(1)
+        if validate_gateway_fqdn_server(gateway_fqdn_server):
+            os.environ['q_gateway_fqdn_server'] = gateway_fqdn_server
+        return True
+    else:
+        return False
+
+
+def if_memory_credentials():
+    def stdin_help():
+        print(f"You selected -m memory, but there is an issue with your environment variables.")
+        print(f"Please check your exported q_username, q_password and q_api_fqdn_server.")
+        print(f"Please rerun when ready.")
+
+    if command_line_arguments.memory_credentials is not None:
+        if 'q_username' in os.environ.keys() and \
+                'q_password' in os.environ.keys() and \
+                'q_api_fqdn_server' in os.environ.keys():
+            pass
+        else:
+            print("Missing q_username, q_password or q_api_fqdn_server from environment...")
+            stdin_help()
+            exit(1)
+
+        api_fqdn_server = os.environ['q_api_fqdn_server']
+        username = os.environ['q_username']
+        password = os.environ['q_password']
+        gateway_fqdn_server = ""
+        if 'gateway_fqdn_server' in os.environ.keys():
+            gateway_fqdn_server = os.environ['gateway_fqdn_server']
+
+        if validate_username(username) and validate_password(password) and validate_api_fqdn_server(api_fqdn_server):
+            pass
+        else:
+            print("Invalid q_username, q_password or q_api_fqdn_server in environment.  Please review your exports...")
+            stdin_help()
+            exit(1)
+        if validate_gateway_fqdn_server(gateway_fqdn_server):
+            os.environ['q_gateway_fqdn_server'] = gateway_fqdn_server
+        return True
+    else:
+        return False
+
+
 def if_update_credentials(first_time=False):
     if command_line_arguments.credentials is not None or first_time is not False:
         etld_lib_config.main()
@@ -138,6 +268,9 @@ def if_update_credentials(first_time=False):
             print(f"You have updated your credentials.")
             print(f"  Qualys Username: {new_credentials.get('username')}")
             print(f"  Qualys api_fqdn_server: {new_credentials.get('api_fqdn_server')}\n")
+        return True
+    else:
+        return False
 
 
 def start_etl_knowledgebase():
@@ -220,6 +353,9 @@ def if_qualys_test_login(first_time=False):
                   f"Succeeded at {credentials.get('api_fqdn_server')}\n"
                   f"    with HTTPS Return Code: {etld_lib_credentials.http_return_code}.")
         etld_lib_functions.main(log_level=logging.WARN, my_logger_prog_name='qetl_manage_user')
+        return True
+    else:
+        return False
 
 
 def if_qualys_test_gateway_login(first_time=False):
@@ -246,6 +382,9 @@ def if_print_report():
             spacer = '    ' * depth
             print(f'{spacer}+ {path.name}')
         print("\n")
+        return True
+    else:
+        return False
 
 
 def help_message(notes):
@@ -265,14 +404,18 @@ def help_message(notes):
                                    1) /home/dgregory/opt/qetl/users/q_username 
                                    2) /opt/qetl/users/q_username
       -e etl module name,     --execute_etl_module module name
-                                  Ex.  -e etl_knowledgebase or -e etl_host_list or -e etl_host_list_detection
+                                  Ex.  -e etl_knowledgebase or -e etl_host_list or -e etl_host_list_detection -e etl_asset_inventory
       -d YYMMDDThh:mm:ssZ,    --datetime        YYYY-MM-DDThh:mm:ssZ UTC. Get All Data On or After Date. 
                                                 Ex. 1970-01-01T00:00:00Z acts as flag to obtain all data.
       -c, --credentials       update qualys api user credentials: qualys username, password or api_fqdn_server
       -t, --test              test qualys credentials
-      -l, --logs              detailed logs sent to stdout
+      -l, --logs              detailed logs sent to stdout for testing qualys credentials
       -r, --report            brief report of the users directory structure.
-     
+      -p, --prompt-credentials prompt user for credentials, also accepts stdin with credentials piped to program.
+      -m, --memory-credentials get credentials from environment: q_username, q_password, q_api_fqdn_server
+      -s, --stdin-credentials  send credentials in json to stdin. 
+                               Example:
+                               {"q_username": "your userid", "q_password": "your password", "q_api_fqdn_server": "api fqdn", "q_gateway_fqdn_server": "gateway api fqdn"}
     '''
     print(f"{help_mess}")
 
@@ -322,13 +465,19 @@ def get_command_line_arguments(args=None):
     global command_line_arguments
     parser = argparse.ArgumentParser(description='Setup and execute etl for your qualys qetl users.')
     parser.add_argument('-u', '--qetl_user_home_dir', default=None, help="Please enter -u option")
-    parser.add_argument('-e', '--execute_etl_module', default=None, help='Execute etl_knowledgebase, etl_host_list or etl_host_list_detection')
+    parser.add_argument('-e', '--execute_etl_module', default=None,
+                        help='Execute etl_knowledgebase, etl_host_list, etl_host_list_detection, etl_asset_inventory')
     parser.add_argument('-d', '--datetime', default=None,
                         help='YYYY-MM-DDThh:mm:ssZ UTC. Get All Data On or After Date.  Ex. 1970-01-01T00:00:00Z acts as flag to obtain all data.')
     parser.add_argument('-c', '--credentials', default=None, action="store_true",
-                        help='update qualys api user credentials: qualys uername, password or api_fqdn_server')
+                        help='update qualys api user credentials stored on disk: qualys uername, password or api_fqdn_server')
     parser.add_argument('-t', '--test', default=None, action="store_true", help='test qualys credentials')
-    parser.add_argument('-l', '--logs', default=None, action="store_true", help='detailed logs sent to stdout')
+    parser.add_argument('-l', '--logs', default=None, action="store_true", help='detailed logs sent to stdout for test qualys credentials')
+    parser.add_argument('-p', '--prompt_credentials', default=None, action="store_true", help='prompt user for credentials')
+    parser.add_argument('-s', '--stdin_credentials', default=None, action="store_true",
+                        help='read stdin credentials json {"q_username":"your userid", "q_password":"your password", "q_api_fqdn_server":"api fqdn", "q_gateway_fqdn_server":"gateway api fqdn"}')
+    parser.add_argument('-m', '--memory_credentials', default=None, action="store_true",
+                        help='Get credentials from environment variables in memory: q_username, q_password, q_api_fqdn_server, and optionally add q_gateway_fqdn_server. Ex. export q_username=myuser')
     parser.add_argument('-r', '--report', default=None, action="store_true",
                         help='Brief report of the users directory structure.')
     command_line_arguments = parser.parse_args(args)
@@ -387,10 +536,21 @@ def main():
     get_command_line_arguments(sys.argv[1:])
     test_command_line_arguments()
     setup_qetl_user_home_dir_environment()
-    if_update_credentials()
+    if if_stdin_credentials():
+        pass
+    elif if_prompt_credentials():
+        pass
+    elif if_memory_credentials():
+        pass
+    elif if_update_credentials():
+        pass
+
     if_qualys_test_login()
-    if_execute_etl_module()
-    if_print_report()
+
+    if if_print_report():
+        pass
+    else:
+        if_execute_etl_module()
 
 
 if __name__ == '__main__':
